pub struct IdentityVerification {Show 18 fields
request: OnceCell<VerificationRequest>,
request_changes_abort_handle: RefCell<Option<AbortHandle>>,
verification: RefCell<Option<Verification>>,
verification_changes_abort_handle: RefCell<Option<AbortHandle>>,
user: BoundConstructOnlyObject<User>,
room: WeakRef<Room>,
membership_handler: RefCell<Option<SignalHandlerId>>,
state: Cell<VerificationState>,
was_accepted: Cell<bool>,
is_finished: PhantomData<bool>,
supported_methods: RefCell<Vec<VerificationMethod>>,
flow_id: PhantomData<String>,
received_time: OnceCell<DateTime>,
received_timeout_source: RefCell<Option<SourceId>>,
display_name: PhantomData<String>,
pub(super) qr_code: RefCell<Option<QrCode>>,
pub(super) qrcode_scanner: RefCell<Option<QrCodeScanner>>,
was_viewed: Cell<bool>,
}Fields
request: OnceCell<VerificationRequest>The SDK’s verification request.
request_changes_abort_handle: RefCell<Option<AbortHandle>>verification: RefCell<Option<Verification>>The SDK’s verification, if one was started.
verification_changes_abort_handle: RefCell<Option<AbortHandle>>user: BoundConstructOnlyObject<User>The user to verify.
room: WeakRef<Room>The room of this verification, if any.
membership_handler: RefCell<Option<SignalHandlerId>>state: Cell<VerificationState>The state of this verification
was_accepted: Cell<bool>Whether the verification request was accepted.
It means that the verification reached at least the Ready state.
is_finished: PhantomData<bool>Whether this verification is finished.
supported_methods: RefCell<Vec<VerificationMethod>>The supported methods of the verification request.
flow_id: PhantomData<String>The flow ID of this verification.
received_time: OnceCell<DateTime>The time and date when the verification request was received.
received_timeout_source: RefCell<Option<SourceId>>display_name: PhantomData<String>The display name of this verification.
qr_code: RefCell<Option<QrCode>>The QR Code, if the QrCodeShowV1 method is supported.
qrcode_scanner: RefCell<Option<QrCodeScanner>>The QR code scanner, if the user wants to scan a QR Code and we have access to the camera.
was_viewed: Cell<bool>Whether this verification was viewed by the user.
Implementations
Sourceimpl IdentityVerification
impl IdentityVerification
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl IdentityVerification
impl IdentityVerification
Sourcepub(super) async fn set_request(&self, request: VerificationRequest)
pub(super) async fn set_request(&self, request: VerificationRequest)
Set the SDK’s verification request.
Sourcepub(super) fn set_state(&self, state: VerificationState)
pub(super) fn set_state(&self, state: VerificationState)
Set the state of this verification.
Sourcefn is_finished(&self) -> bool
fn is_finished(&self) -> bool
Whether this verification is finished.
Sourcefn set_supported_methods(&self, supported_methods: Vec<VerificationMethod>)
fn set_supported_methods(&self, supported_methods: Vec<VerificationMethod>)
Set the supported methods of this verification.
Sourcefn supported_methods(&self) -> VerificationSupportedMethods
fn supported_methods(&self) -> VerificationSupportedMethods
The supported methods of this verifications.
Sourcefn display_name(&self) -> String
fn display_name(&self) -> String
The display name of this verification request.
Sourcefn set_was_viewed(&self, was_viewed: bool)
fn set_was_viewed(&self, was_viewed: bool)
Set whether this verification was viewed by the user.
Sourcefn set_was_accepted(&self, was_accepted: bool)
fn set_was_accepted(&self, was_accepted: bool)
Set whether this request was accepted.
Sourceasync fn handle_request_state(&self, state: VerificationRequestState)
async fn handle_request_state(&self, state: VerificationRequestState)
Handle a change in the request’s state.
Sourcefn handle_cancelled_state(&self, cancel_info: &CancelInfo)
fn handle_cancelled_state(&self, cancel_info: &CancelInfo)
Handle when the request was cancelled.
Sourceasync fn set_verification(&self, verification: Verification)
async fn set_verification(&self, verification: Verification)
Set the SDK’s Verification.
Sourcefn handle_qr_verification_state(&self, state: QrVerificationState)
fn handle_qr_verification_state(&self, state: QrVerificationState)
Handle a change in the QR verification’s state.
Sourcepub(super) fn qr_verification(&self) -> Option<QrVerification>
pub(super) fn qr_verification(&self) -> Option<QrVerification>
The SDK’s QR verification, if one was started.
Sourceasync fn handle_sas_verification_state(&self, state: SasState)
async fn handle_sas_verification_state(&self, state: SasState)
Handle a change in the SAS verification’s state.
Sourcepub(super) fn sas_verification(&self) -> Option<SasVerification>
pub(super) fn sas_verification(&self) -> Option<SasVerification>
The SDK’s SAS verification, if one was started.
Sourceasync fn load_qr_code(&self) -> bool
async fn load_qr_code(&self) -> bool
Try to load the QR Code.
Return true if it was successfully loaded, false otherwise.